<?php
require_once '../phpoot.php';
$tmpl = new phpoot;
//$tmpl->setErrorHandling(PEAR_ERROR_PRINT);
$tmpl->setTemplateFile('./helloworld.html');
$model_data = array(
  'title' => 'Hello World',
  'body'  => 'PHPOOT is a template engine for PHP'
);
$tmpl->display($model_data);
?>